@@ -28,7 +28,7 @@ our @EXPORT = qw(
 sectorsummary
 );
 
-our $VERSION = '0.01';
+our $VERSION = '0.07';
 
 
 
@@ -46,7 +46,6 @@ sub sectorsummary{
 
 
     my $tree = HTML::TreeBuilder->new;
-#    $content = utf8::decode($content);
 
     
     $tree->parse($content);
@@ -76,11 +75,15 @@ sub sectorsummary{
         if($_ =~/Non*Cyclical/ && $_ =~/\+/){
             @set = split /\+/,$_;
             $set[0] = "ConsNonCyclical";
+
+
             $out{sectors}->{pos}->{$set[0]}=sprintf("%3.3f",$set[1]);
         }elsif($_ =~/Non*Cyclical/ && $_ =~/\-/){
             @set = split /\-/,$_;
             $set[0] = "ConsNonCyclical";
             $set[1] = $set[2];
+
+            
             $out{sectors}->{pos}->{$set[0]}=sprintf("%3.3f",$set[1]);
         
         }else{
@@ -88,9 +91,14 @@ sub sectorsummary{
             
             if($_ =~ /\+/){
                 @set = split /\+/,$_;
+                
                 $out{sectors}->{pos}->{$set[0]}=sprintf("%3.3f",$set[1]);
             }else{
                 @set = split /-/,$_;
+
+                
+                
+                $set[1]=0.00 unless($set[1]);
                 $out{sectors}->{neg}->{$set[0]}=sprintf("%3.3f",$set[1]);
             }
             
